@@ -41,7 +41,6 @@
 #include "kleo/dn.h"
 #include "utils/filesystemwatcher.h"
 
-#include <gpgme++/gpgmepp_version.h>
 #include <gpgme++/error.h>
 #include <gpgme++/key.h>
 #include <gpgme++/decryptionresult.h>
@@ -199,12 +198,6 @@ public:
     void ensureCachePopulated() const;
 
     void updateGroupCache() {
-
-#if GPGMEPP_VERSION < 0x10900 // 1.9.0
-        // In GPGME before 1.9.0 string lists are
-        // broken from cryptoconfig.
-        return;
-#else
         // Update Group Keys
         // this is a quick thing as it only involves reading the config
         // so no need for a job.
@@ -242,7 +235,6 @@ public:
             vec.push_back(key);
             m_groups.insert(name, vec);
         }
-#endif
     }
 
 private:
@@ -1143,7 +1135,7 @@ Error KeyCache::RefreshKeysJob::Private::startKeyListing(GpgME::Protocol proto)
 #if 0
     aheinecke: 2017.01.12:
 
-    For unkown reasons the new style connect fails at runtime
+    For unknown reasons the new style connect fails at runtime
     over library borders into QGpgME from the GpgME repo
     when cross compiled for Windows and default arguments
     are used in the Signal.
@@ -1196,17 +1188,17 @@ bool KeyCache::pgpOnly() const
     return d->m_pgpOnly;
 }
 
-static bool keyIsOk(const Key k)
+static bool keyIsOk(const Key &k)
 {
     return !k.isExpired() && !k.isRevoked() && !k.isInvalid() && !k.isDisabled();
 }
 
-static bool uidIsOk(const UserID uid)
+static bool uidIsOk(const UserID &uid)
 {
     return keyIsOk(uid.parent()) && !uid.isRevoked() && !uid.isInvalid();
 }
 
-static bool subkeyIsOk(const Subkey s)
+static bool subkeyIsOk(const Subkey &s)
 {
     return !s.isRevoked() && !s.isInvalid() && !s.isDisabled();
 }
@@ -1220,9 +1212,9 @@ std::vector<GpgME::Key> KeyCache::findBestByMailBox(const char *addr, GpgME::Pro
         return ret;
     }
     if (proto == Protocol::OpenPGP) {
-        // Groups take precendece over autmatic keys. We return all here
+        // Groups take precedence over automatic keys. We return all here
         // so if a group key for example is expired we can show that.
-        ret = getGroupKeys(addr);
+        ret = getGroupKeys(QString::fromUtf8(addr));
         if (!ret.empty()) {
             return ret;
         }
