@@ -38,7 +38,7 @@
 #include "utils/formatting.h"
 
 #ifdef KLEO_MODEL_TEST
-# include "modeltest.h"
+# include <QAbstractItemModelTester>
 #endif
 
 #include <Libkleo/KeyFilterManager>
@@ -198,8 +198,15 @@ QVariant AbstractKeyListModel::headerData(int section, Qt::Orientation o, int ro
             case Validity:         return i18n("User-IDs");
             case ValidFrom:        return i18n("Valid From");
             case ValidUntil:       return i18n("Valid Until");
-            case TechnicalDetails: return i18n("Details");
+            case TechnicalDetails: return i18n("Protocol");
             case ShortKeyID:       return i18n("Key-ID");
+            case KeyID:            return i18n("Key-ID");
+            case Fingerprint:      return i18n("Fingerprint");
+            case Issuer:           return i18n("Issuer");
+            case SerialNumber:     return i18n("Serial Number");
+            case Origin:           return i18n("Origin");
+            case LastUpdate:       return i18n("Last Update");
+            case OwnerTrust:       return i18n("Certification Trust");
             case NumColumns:;
             }
     return QVariant();
@@ -265,15 +272,29 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
             return Formatting::type(key);
         case ShortKeyID:
             return QString::fromLatin1(key.shortKeyID());
+        case KeyID:
+            return Formatting::prettyID(key.keyID());
         case Summary:
             return Formatting::summaryLine(key);
+        case Fingerprint:
+            return Formatting::prettyID(key.primaryFingerprint());
+        case Issuer:
+            return QString::fromUtf8(key.issuerName());
+        case Origin:
+            return Formatting::origin(key.origin());
+        case LastUpdate:
+            return Formatting::dateString(key.lastUpdate());
+        case SerialNumber:
+            return QString::fromUtf8(key.issuerSerial());
+        case OwnerTrust:
+            return Formatting::ownerTrustShort(key.ownerTrust());
         case NumColumns:
             break;
         }
     } else if (role == Qt::ToolTipRole) {
         return Formatting::toolTip(key, toolTipOptions());
     } else if (role == Qt::FontRole) {
-        return KeyFilterManager::instance()->font(key, (column == ShortKeyID) ? QFont(QStringLiteral("courier")) : QFont());
+        return KeyFilterManager::instance()->font(key, (column == ShortKeyID || column == KeyID || column == Fingerprint) ? QFont(QStringLiteral("monospace")) : QFont());
     } else if (role == Qt::DecorationRole) {
         return column == Icon ? returnIfValid(KeyFilterManager::instance()->icon(key)) : QVariant();
     } else if (role == Qt::BackgroundRole) {
@@ -324,7 +345,7 @@ class FlatKeyListModel
     Q_OBJECT
 public:
     explicit FlatKeyListModel(QObject *parent = nullptr);
-    ~FlatKeyListModel();
+    ~FlatKeyListModel() override;
 
     int rowCount(const QModelIndex &pidx) const override
     {
@@ -349,7 +370,7 @@ class HierarchicalKeyListModel : public AbstractKeyListModel
     Q_OBJECT
 public:
     explicit HierarchicalKeyListModel(QObject *parent = nullptr);
-    ~HierarchicalKeyListModel();
+    ~HierarchicalKeyListModel() override;
 
     int rowCount(const QModelIndex &pidx) const override;
     using AbstractKeyListModel::index;
@@ -781,7 +802,7 @@ QList<QModelIndex> HierarchicalKeyListModel::doAddKeys(const std::vector<Key> &k
         {
             addKeyWithParent(issuer_fpr, key);
         } else
-            // parent does't exist yet...
+            // parent doesn't exist yet...
         {
             addKeyWithoutParent(issuer_fpr, key);
         }
@@ -902,7 +923,7 @@ AbstractKeyListModel *AbstractKeyListModel::createFlatKeyListModel(QObject *p)
 {
     AbstractKeyListModel *const m = new FlatKeyListModel(p);
 #ifdef KLEO_MODEL_TEST
-    new ModelTest(m, p);
+    new QAbstractItemModelTester(m, p);
 #endif
     return m;
 }
@@ -912,7 +933,7 @@ AbstractKeyListModel *AbstractKeyListModel::createHierarchicalKeyListModel(QObje
 {
     AbstractKeyListModel *const m = new HierarchicalKeyListModel(p);
 #ifdef KLEO_MODEL_TEST
-    new ModelTest(m, p);
+    new QAbstractItemModelTester(m, p);
 #endif
     return m;
 }
