@@ -29,19 +29,18 @@
     your version.
 */
 
-#include "backends/qgpgme/qgpgmecryptoconfig.h"
-#include "backends/qgpgme/qgpgmenewcryptoconfig.h"
+#include <qgpgme/qgpgmenewcryptoconfig.h>
 
 #include <QCoreApplication>
 #include <iostream>
 
 using namespace std;
+using namespace QGpgME;
 
 #include <gpgme++/global.h>
 #include <gpgme++/error.h>
 
 #include <stdlib.h>
-#include <assert.h>
 
 int main(int argc, char **argv)
 {
@@ -50,20 +49,10 @@ int main(int argc, char **argv)
         return 1;
     }
 
-    const bool newCryptoConfig = argc == 2 && qstrcmp(argv[1], "--new") == 0;
-    if (newCryptoConfig) {
-        argc = 1;    // hide from KDE
-    }
-
     QCoreApplication::setApplicationName(QStringLiteral("test_cryptoconfig"));
     QCoreApplication app(argc, argv);
 
-    Kleo::CryptoConfig *config = 0;
-    if (newCryptoConfig) {
-        config = new QGpgMENewCryptoConfig;
-    } else {
-        config = new QGpgMECryptoConfig;
-    }
+    QGpgME::CryptoConfig *config = new QGpgMENewCryptoConfig;
 
     // Dynamic querying of the options
     cout << "Components:" << endl;
@@ -71,53 +60,53 @@ int main(int argc, char **argv)
 
     for (QStringList::Iterator compit = components.begin(); compit != components.end(); ++compit) {
         cout << "Component " << (*compit).toLocal8Bit().constData() << ":" << endl;
-        const Kleo::CryptoConfigComponent *comp = config->component(*compit);
-        assert(comp);
+        const QGpgME::CryptoConfigComponent *comp = config->component(*compit);
+        Q_ASSERT(comp);
         QStringList groups = comp->groupList();
         for (QStringList::Iterator groupit = groups.begin(); groupit != groups.end(); ++groupit) {
-            const Kleo::CryptoConfigGroup *group = comp->group(*groupit);
-            assert(group);
+            const QGpgME::CryptoConfigGroup *group = comp->group(*groupit);
+            Q_ASSERT(group);
             cout << " Group " << (*groupit).toLocal8Bit().constData() << ": descr=\"" << group->description().toLocal8Bit().constData() << "\""
                  << " level=" << group->level() << endl;
             QStringList entries = group->entryList();
             for (QStringList::Iterator entryit = entries.begin(); entryit != entries.end(); ++entryit) {
-                const Kleo::CryptoConfigEntry *entry = group->entry(*entryit);
-                assert(entry);
+                const QGpgME::CryptoConfigEntry *entry = group->entry(*entryit);
+                Q_ASSERT(entry);
                 cout << "  Entry " << (*entryit).toLocal8Bit().constData() << ":"
                      << " descr=\"" << entry->description().toLocal8Bit().constData() << "\""
                      << " " << (entry->isSet() ? "is set" : "is not set");
                 if (!entry->isList())
                     switch (entry->argType()) {
-                    case Kleo::CryptoConfigEntry::ArgType_None:
+                    case QGpgME::CryptoConfigEntry::ArgType_None:
                         break;
-                    case Kleo::CryptoConfigEntry::ArgType_Int:
+                    case QGpgME::CryptoConfigEntry::ArgType_Int:
                         cout << " int value=" << entry->intValue();
                         break;
-                    case Kleo::CryptoConfigEntry::ArgType_UInt:
+                    case QGpgME::CryptoConfigEntry::ArgType_UInt:
                         cout << " uint value=" << entry->uintValue();
                         break;
-                    case Kleo::CryptoConfigEntry::ArgType_LDAPURL:
-                    case Kleo::CryptoConfigEntry::ArgType_Path:
+                    case QGpgME::CryptoConfigEntry::ArgType_LDAPURL:
+                    case QGpgME::CryptoConfigEntry::ArgType_Path:
                     // fallthrough
-                    case Kleo::CryptoConfigEntry::ArgType_DirPath:
+                    case QGpgME::CryptoConfigEntry::ArgType_DirPath:
                     // fallthrough
-                    case Kleo::CryptoConfigEntry::ArgType_String:
+                    case QGpgME::CryptoConfigEntry::ArgType_String:
 
                         cout << " string value=" << entry->stringValue().toLocal8Bit().constData();
                         break;
-                    case Kleo::CryptoConfigEntry::NumArgType:
+                    case QGpgME::CryptoConfigEntry::NumArgType:
                         // just metadata and should never actually occur in the switch
                         break;
                     }
                 else { // lists
                     switch (entry->argType()) {
-                    case Kleo::CryptoConfigEntry::ArgType_None: {
+                    case QGpgME::CryptoConfigEntry::ArgType_None: {
                         cout << " set " << entry->numberOfTimesSet() << " times";
                         break;
                     }
-                    case Kleo::CryptoConfigEntry::ArgType_Int: {
-                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this assert is wrong:
-                        // assert( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
+                    case QGpgME::CryptoConfigEntry::ArgType_Int: {
+                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this Q_ASSERT is wrong:
+                        // Q_ASSERT( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
                         std::vector<int> lst = entry->intValueList();
                         QString str;
                         for (std::vector<int>::const_iterator it = lst.begin(); it != lst.end(); ++it) {
@@ -126,9 +115,9 @@ int main(int argc, char **argv)
                         cout << " int values=" << str.toLocal8Bit().constData();
                         break;
                     }
-                    case Kleo::CryptoConfigEntry::ArgType_UInt: {
-                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this assert is wrong:
-                        // assert( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
+                    case QGpgME::CryptoConfigEntry::ArgType_UInt: {
+                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this Q_ASSERT is wrong:
+                        // Q_ASSERT( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
                         std::vector<uint> lst = entry->uintValueList();
                         QString str;
                         for (std::vector<uint>::const_iterator it = lst.begin(); it != lst.end(); ++it) {
@@ -137,25 +126,25 @@ int main(int argc, char **argv)
                         cout << " uint values=" << str.toLocal8Bit().constData();
                         break;
                     }
-                    case Kleo::CryptoConfigEntry::ArgType_LDAPURL: {
-                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this assert is wrong:
-                        // assert( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
-                        QList<QUrl> urls = entry->urlValueList();
+                    case QGpgME::CryptoConfigEntry::ArgType_LDAPURL: {
+                        // (marc) if an entry isn't optional, you have to unset it for the default to take effect, so this Q_ASSERT is wrong:
+                        // Q_ASSERT( entry->isOptional() ); // empty lists must be allowed (see https://www.intevation.de/roundup/aegypten/issue121)
+                        const QList<QUrl> urls = entry->urlValueList();
                         cout << " url values ";
-                        Q_FOREACH (const QUrl &url, urls) {
+                        for (const QUrl &url : urls) {
                             cout << url.toString().toLocal8Bit().constData() << " ";
                         }
                         cout << endl;
                     }
                     // fallthrough
-                    case Kleo::CryptoConfigEntry::ArgType_Path:
+                    case QGpgME::CryptoConfigEntry::ArgType_Path:
                     // fallthrough
-                    case Kleo::CryptoConfigEntry::ArgType_DirPath:
+                    case QGpgME::CryptoConfigEntry::ArgType_DirPath:
                     // fallthrough
-                    case Kleo::CryptoConfigEntry::ArgType_String:
+                    case QGpgME::CryptoConfigEntry::ArgType_String:
                     // fallthrough string value lists were removed from
                     // gpgconf in 2008
-                    case Kleo::CryptoConfigEntry::NumArgType:
+                    case QGpgME::CryptoConfigEntry::NumArgType:
                         // just metadata and should never actually occur in the switch
                         break;
                     }
@@ -168,61 +157,61 @@ int main(int argc, char **argv)
 
     {
         // Static querying of a single boolean option
-        static const char s_groupName[] = "Monitor";
-        static const char s_entryName[] = "quiet";
-        Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+        static const QString s_groupName = QStringLiteral("Monitor");
+        static const QString s_entryName = QStringLiteral("quiet");
+        QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
         if (entry) {
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_None);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_None);
             bool val = entry->boolValue();
             cout << "quiet option initially: " << (val ? "is set" : "is not set") << endl;
 
             entry->setBoolValue(!val);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             // Clear cached values!
             config->clear();
 
             // Check new value
-            Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(entry);
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_None);
+            QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+            Q_ASSERT(entry);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_None);
             cout << "quiet option now: " << (val ? "is set" : "is not set") << endl;
-            assert(entry->boolValue() == !val);
+            Q_ASSERT(entry->boolValue() == !val);
 
             // Set to default
             entry->resetToDefault();
-            assert(entry->boolValue() == false);   // that's the default
-            assert(entry->isDirty());
-            assert(!entry->isSet());
+            Q_ASSERT(entry->boolValue() == false);   // that's the default
+            Q_ASSERT(entry->isDirty());
+            Q_ASSERT(!entry->isSet());
             config->sync(true);
             config->clear();
 
             // Check value
             entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(!entry->isDirty());
-            assert(!entry->isSet());
+            Q_ASSERT(!entry->isDirty());
+            Q_ASSERT(!entry->isSet());
             cout << "quiet option reset to default: " << (entry->boolValue() ? "is set" : "is not set") << endl;
-            assert(entry->boolValue() == false);
+            Q_ASSERT(entry->boolValue() == false);
 
             // Reset old value
             entry->setBoolValue(val);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             cout << "quiet option reset to initial: " << (val ? "is set" : "is not set") << endl;
         } else {
-            cout << "Entry 'dirmngr/" << s_groupName << "/" << s_entryName << "' not found" << endl;
+            cout << "Entry 'dirmngr/" << qPrintable(s_groupName) << "/" << qPrintable(s_entryName) << "' not found" << endl;
         }
     }
 
     {
         // Static querying and setting of a single int option
-        static const char s_groupName[] = "LDAP";
-        static const char s_entryName[] = "ldaptimeout";
-        Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+        static const QString s_groupName = QStringLiteral("LDAP");
+        static const QString s_entryName = QStringLiteral("ldaptimeout");
+        QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
         if (entry) {
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_UInt);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_UInt);
             uint val = entry->uintValue();
             cout << "LDAP timeout initially: " << val << " seconds." << endl;
 
@@ -230,58 +219,58 @@ int main(int argc, char **argv)
             //system( "echo 'ldaptimeout:0:101' | gpgconf --change-options dirmngr" );
             // Now let's do it with the C++ API instead
             entry->setUIntValue(101);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             // Clear cached values!
             config->clear();
 
             // Check new value
-            Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(entry);
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_UInt);
+            QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+            Q_ASSERT(entry);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_UInt);
             cout << "LDAP timeout now: " << entry->uintValue() << " seconds." << endl;
-            assert(entry->uintValue() == 101);
+            Q_ASSERT(entry->uintValue() == 101);
 
             // Set to default
             entry->resetToDefault();
-            assert(entry->uintValue() == 100);
-            assert(entry->isDirty());
-            assert(!entry->isSet());
+            Q_ASSERT(entry->uintValue() == 100);
+            Q_ASSERT(entry->isDirty());
+            Q_ASSERT(!entry->isSet());
             config->sync(true);
             config->clear();
 
             // Check value
             entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(!entry->isDirty());
-            assert(!entry->isSet());
+            Q_ASSERT(!entry->isDirty());
+            Q_ASSERT(!entry->isSet());
             cout << "LDAP timeout reset to default, " << entry->uintValue() << " seconds." << endl;
-            assert(entry->uintValue() == 100);
+            Q_ASSERT(entry->uintValue() == 100);
 
             // Reset old value
             entry->setUIntValue(val);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             cout << "LDAP timeout reset to initial " << val << " seconds." << endl;
         } else {
-            cout << "Entry 'dirmngr/" << s_groupName << "/" << s_entryName << "' not found" << endl;
+            cout << "Entry 'dirmngr/" << qPrintable(s_groupName) << "/" << qPrintable(s_entryName) << "' not found" << endl;
         }
     }
 
     {
         // Static querying and setting of a single string option
-        static const char s_groupName[] = "Debug";
-        static const char s_entryName[] = "log-file";
-        Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+        static const QString s_groupName = QStringLiteral("Debug");
+        static const QString s_entryName = QStringLiteral("log-file");
+        QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
         if (entry) {
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_Path);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_Path);
             QString val = entry->stringValue();
             cout << "Log-file initially: " << val.toLocal8Bit().constData() << endl;
 
             // Test setting the option, sync'ing, then querying again
             entry->setStringValue(QStringLiteral("/tmp/test:%e5ä"));
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             // Let's see how it prints it
@@ -291,11 +280,11 @@ int main(int argc, char **argv)
             config->clear();
 
             // Check new value
-            Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(entry);
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_Path);
+            QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+            Q_ASSERT(entry);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_Path);
             cout << "Log-file now: " << entry->stringValue().toLocal8Bit().constData() << endl;
-            assert(entry->stringValue() == QStringLiteral("/tmp/test:%e5ä"));     // (or even with %e5 decoded)
+            Q_ASSERT(entry->stringValue() == QStringLiteral("/tmp/test:%e5ä"));     // (or even with %e5 decoded)
 
             // Reset old value
 #if 0
@@ -308,26 +297,26 @@ int main(int argc, char **argv)
             system(sys.data());
 #endif
             entry->setStringValue(val);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             cout << "Log-file reset to initial " << val.toLocal8Bit().constData() << endl;
         } else {
-            cout << "Entry 'dirmngr/" << s_groupName << "/" << s_entryName << "' not found" << endl;
+            cout << "Entry 'dirmngr/" << qPrintable(s_groupName) << "/" << qPrintable(s_entryName) << "' not found" << endl;
         }
     }
 
     {
         // Static querying and setting of the LDAP URL list option
-        static const char s_groupName[] = "LDAP";
-        static const char s_entryName[] = "LDAP Server";
-        Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+        static const QString s_groupName = QStringLiteral("LDAP");
+        static const QString s_entryName = QStringLiteral("LDAP Server");
+        QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
         if (entry) {
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_LDAPURL);
-            assert(entry->isList());
-            QList<QUrl> val = entry->urlValueList();
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_LDAPURL);
+            Q_ASSERT(entry->isList());
+            const QList<QUrl> val = entry->urlValueList();
             cout << "URL list initially: ";
-            Q_FOREACH (const QUrl &url, val) {
+            for (const QUrl &url : val) {
                 cout << url.toString().toLocal8Bit().constData() << ", ";
             }
             cout << endl;
@@ -338,10 +327,10 @@ int main(int argc, char **argv)
             lst << QUrl(QStringLiteral("ldap://foo:389?a:b c"));
             lst << QUrl(QStringLiteral("ldap://server:389?a=b,c=DE"));   // the query contains a literal ','
             //cout << " trying to set: " << lst.toStringList().join(", ").local8Bit() << endl;
-            assert(lst[0].query() == "b");
-            assert(lst[1].query() == "a:b c");   // see, the space got _not_escaped
+            Q_ASSERT(lst[0].query() == QLatin1Char('b'));
+            Q_ASSERT(lst[1].query() == QStringLiteral("a:b c"));   // see, the space got _not_escaped
             entry->setURLValueList(lst);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             // Let's see how it prints it
@@ -351,34 +340,34 @@ int main(int argc, char **argv)
             config->clear();
 
             // Check new value
-            Kleo::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
-            assert(entry);
-            assert(entry->argType() == Kleo::CryptoConfigEntry::ArgType_LDAPURL);
-            assert(entry->isList());
+            QGpgME::CryptoConfigEntry *entry = config->entry(QStringLiteral("dirmngr"), s_groupName, s_entryName);
+            Q_ASSERT(entry);
+            Q_ASSERT(entry->argType() == QGpgME::CryptoConfigEntry::ArgType_LDAPURL);
+            Q_ASSERT(entry->isList());
             // Get QUrl form
-            QList<QUrl> newlst = entry->urlValueList();
+            const QList<QUrl> newlst = entry->urlValueList();
             cout << "URL list now: ";
-            Q_FOREACH (const QUrl &url, newlst) {
+            for (const QUrl &url : newlst) {
                 cout << url.toString().toLocal8Bit().constData() << endl;
             }
             cout << endl;
-            assert(newlst.count() == 3);
-            assert(newlst[0].url() == lst[0].url());
-            assert(newlst[1].url() == lst[1].url());
-            assert(newlst[2].url() == lst[2].url());
+            Q_ASSERT(newlst.count() == 3);
+            Q_ASSERT(newlst[0].url() == lst[0].url());
+            Q_ASSERT(newlst[1].url() == lst[1].url());
+            Q_ASSERT(newlst[2].url() == lst[2].url());
 
             // Reset old value
             entry->setURLValueList(val);
-            assert(entry->isDirty());
+            Q_ASSERT(entry->isDirty());
             config->sync(true);
 
             cout << "URL list reset to initial: ";
-            Q_FOREACH (const QUrl &url, newlst) {
+            for (const QUrl &url : qAsConst(newlst)) {
                 cout << url.toString().toLocal8Bit().constData() << ", ";
             }
             cout << endl;
         } else {
-            cout << "Entry 'dirmngr/" << s_groupName << "/" << s_entryName << "' not found" << endl;
+            cout << "Entry 'dirmngr/" << qPrintable(s_groupName) << "/" << qPrintable(s_entryName) << "' not found" << endl;
         }
     }
 
