@@ -49,14 +49,9 @@
 #include <QTextDocument> // for Qt::escape
 #include <QLocale>
 #include <QIcon>
-#include <QColor>
 #include <QRegularExpression>
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION > 0x10900
-# define GPGME_HAS_KEY_IS_DEVS
-#endif
-
+#include "models/keycache.h"
 
 using namespace GpgME;
 using namespace Kleo;
@@ -291,7 +286,7 @@ QString format_keyusage(const Key &key)
     if (key.canAuthenticate()) {
         capabilities.push_back(i18n("SSH Authentication"));
     }
-    return capabilities.join(QStringLiteral(", "));
+    return capabilities.join(QLatin1String(", "));
 }
 
 QString format_subkeyusage(const Subkey &subkey)
@@ -313,7 +308,7 @@ QString format_subkeyusage(const Subkey &subkey)
     if (subkey.canAuthenticate()) {
         capabilities.push_back(i18n("SSH Authentication"));
     }
-    return capabilities.join(QStringLiteral(", "));
+    return capabilities.join(QLatin1String(", "));
 }
 
 static QString time_t2string(time_t t)
@@ -507,6 +502,11 @@ QDate expiration_date(const T &tee)
 }
 }
 
+QString Formatting::dateString(time_t t)
+{
+    return date2string(time_t2date(t));
+}
+
 QString Formatting::expirationDateString(const Key &key)
 {
     return expiration_date_string(key.subkey(0));
@@ -678,7 +678,22 @@ QString Formatting::validityShort(const UserID::Signature &sig)
     case UserID::Signature::SigExpired:   return i18n("expired");
     case UserID::Signature::KeyExpired:   return i18n("certificate expired");
     case UserID::Signature::BadSignature: return i18nc("fake/invalid signature", "bad");
-    case UserID::Signature::NoPublicKey:  return i18n("no public key");
+    case UserID::Signature::NoPublicKey: {
+            /* GnuPG returns the same error for no public key as for expired
+             * or revoked certificates. */
+            const auto key = KeyCache::instance()->findByKeyIDOrFingerprint (sig.signerKeyID());
+            if (key.isNull()) {
+                return i18n("no public key");
+            } else if (key.isExpired()) {
+                return i18n("key expired");
+            } else if (key.isRevoked()) {
+                return i18n("key revoked");
+            } else if (key.isDisabled()) {
+                return i18n("key disabled");
+            }
+            /* can't happen */
+            return QStringLiteral("unknown");
+        }
     }
     return QString();
 }
@@ -883,7 +898,7 @@ QString Formatting::usageString(const Subkey &sub)
     if (sub.canAuthenticate()) {
         usageStrings << i18n("Authenticate");
     }
-    return usageStrings.join(QStringLiteral(", "));
+    return usageStrings.join(QLatin1String(", "));
 }
 
 QString Formatting::summaryLine(const Key &key)
@@ -933,12 +948,21 @@ QString Formatting::validity(const UserID &uid)
 
 bool Formatting::uidsHaveFullValidity(const GpgME::Key &key)
 {
+    bool oneValid = false;
     for (const auto &uid: key.userIDs()) {
+        if (uid.isRevoked()) {
+            /* Skip revoked uids */
+            continue;
+        }
         if (uid.validity() < UserID::Validity::Full) {
             return false;
         }
+        /* Only return true if we have found at least one
+         * valid uid. E.g. if all uids are revoked we do
+         * not want to return true here. */
+        oneValid = true;
     }
-    return true;
+    return oneValid;
 }
 
 QString Formatting::complianceMode()
@@ -949,7 +973,7 @@ QString Formatting::complianceMode()
     }
     const QGpgME::CryptoConfigEntry *const entry = config->entry(QStringLiteral("gpg"), QStringLiteral("Configuration"), QStringLiteral("compliance"));
 
-    if (!entry || entry->stringValue() == QStringLiteral("gnupg")) {
+    if (!entry || entry->stringValue() == QLatin1String("gnupg")) {
         return QString();
     }
     return entry->stringValue();
@@ -957,7 +981,6 @@ QString Formatting::complianceMode()
 
 bool Formatting::isKeyDeVs(const GpgME::Key &key)
 {
-#ifdef GPGME_HAS_KEY_IS_DEVS
     for (const auto &sub: key.subkeys()) {
         if (sub.isExpired() || sub.isRevoked()) {
             // Ignore old subkeys
@@ -968,16 +991,13 @@ bool Formatting::isKeyDeVs(const GpgME::Key &key)
         }
     }
     return true;
-#else
-    return false;
-#endif
 }
 
 QString Formatting::complianceStringForKey(const GpgME::Key &key)
 {
     // There will likely be more in the future for other institutions
     // for now we only have DE-VS
-    if (complianceMode() == QStringLiteral("de-vs")) {
+    if (complianceMode() == QLatin1String("de-vs")) {
         if (uidsHaveFullValidity(key) && isKeyDeVs(key)) {
             return i18nc("VS-NfD conforming is a German standard for restricted documents. For which special restrictions about algorithms apply. The string describes if a key is compliant with that..",
                          "May be used for VS-NfD-compliant communication.");
@@ -992,7 +1012,7 @@ QString Formatting::complianceStringForKey(const GpgME::Key &key)
 QString Formatting::complianceStringShort(const GpgME::Key &key)
 {
     if (Formatting::uidsHaveFullValidity(key)) {
-        if (complianceMode() == QStringLiteral("de-vs")
+        if (complianceMode() == QLatin1String("de-vs")
             && Formatting::isKeyDeVs(key)) {
             return QStringLiteral("★ ") +
                 i18nc("VS-NfD-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that a key is compliant with that.",
@@ -1000,6 +1020,9 @@ QString Formatting::complianceStringShort(const GpgME::Key &key)
         }
         return i18nc("As in all user IDs are valid.", "certified");
     }
+    if (key.isExpired()) {
+        return i18n("expired");
+    }
 
     return i18nc("As in not all user IDs are valid.", "not certified");
 }
@@ -1009,5 +1032,27 @@ QString Formatting::prettyID(const char *id)
     if (!id) {
         return QString();
     }
-    return QString::fromLatin1(id).toUpper().replace(QRegularExpression("(....)"), "\\1 ").trimmed();
+    return QString::fromLatin1(id).toUpper().replace(QRegularExpression(QStringLiteral("(....)")), QStringLiteral("\\1 ")).trimmed();
+}
+
+QString Formatting::origin(int o)
+{
+    switch (o) {
+        case Key::OriginKS:
+            return i18n("Keyserver");
+        case Key::OriginDane:
+            return QStringLiteral("DANE");
+        case Key::OriginWKD:
+            return QStringLiteral("WKD");
+        case Key::OriginURL:
+            return QStringLiteral("URL");
+        case Key::OriginFile:
+            return i18n("File import");
+        case Key::OriginSelf:
+            return i18n("Generated");
+        case Key::OriginOther:
+        case Key::OriginUnknown:
+        default:
+          return i18n("Unknown");
+    }
 }
